# libpythonpro
Módulo para exemplificar construção de projetos python no curso pytools

suportada versao 3 de python
1comnado: python -V(maisculo)
2comonado para saber de onde vem o python:where python!
3 criando venv manual mente no terminal:
python -m venv .venv
4 no terminal do powershell do windowns executar o seguinte comando
:Set-ExecutionPolicy -Scope CurrentUser -ExecutionPolicy RemoteSigned
5 comnado : confirma com 's'
6 como .env nao estava aprencendo  var no power shel do pycharm e eceute o seguinte comando:
.venv\Scripts\activate
 assim o vem  sera ativado

7- apos excluir o .venv -
-py -3 -m venv .venv
.venv\Scripts\activate
pip install -r requirements.txt

suportada versao 3 de python

para instalar :

''' console
-py -3 -m venv .venv
.venv\Scripts\activate
pip install -r requirements.txt
'''

para conferir qualidade de codigo:
''' console terminal flake8'''